<?php
namespace Migration\Handler\AheadworksRma;

use Migration\ResourceModel\Record;
use Migration\Handler\AbstractHandler;
use Migration\Handler\HandlerInterface;
use Migration\ResourceModel\Source;
use Aheadworks\Rma\Model\Source\ThreadMessage\Owner;

/**
 * Handler for checking who (admin or customer) left the latest message
 */
class LastReplyCheck extends AbstractHandler implements HandlerInterface
{
    /**
     * @var Source
     */
    private $source;

    /**
     * OrderIdFormat constructor.
     * @param Source $source
     */
    public function __construct(
        Source $source
    ) {
        $this->source = $source;
    }

    /**
     * {@inheritdoc}
     */
    public function handle(Record $recordToHandle, Record $oppositeRecord)
    {
        $this->validate($recordToHandle);
        $requestId = $recordToHandle->getValue('id');
        $lastReplyId = $this->getLastReplyId($requestId);
        if ($lastReplyId == 1) {
            $recordToHandle->setValue($this->field, Owner::CUSTOMER);
        } elseif ($lastReplyId == 2) {
            $recordToHandle->setValue($this->field, Owner::ADMIN);
        }
    }

    /**
     * Get last replied ID
     * @param int $requestId
     * @return int
     */
    private function getLastReplyId($requestId)
    {
        $adapter = $this->source->getAdapter();
        $query = $adapter->getSelect()
            ->from(
                ['aw_rma_entity'],
                []
            )->joinLeft(
                ['aw_rma_entity_comments'],
                'aw_rma_entity.id = aw_rma_entity_comments.entity_id',
                ['owner']
            )->where('aw_rma_entity.id = ?', $requestId);

        if ($ownerColumn = $query->getAdapter()->fetchCol($query)) {
            return end($ownerColumn);
        }
        return 1;
    }
}
