<?php
namespace Migration\Handler\AheadworksRma;

use Migration\ResourceModel\Record;
use Migration\Handler\AbstractHandler;
use Migration\Handler\HandlerInterface;
use Migration\ResourceModel\Destination;
use Aheadworks\Rma\Model\Source\ThreadMessage\Owner;

/**
 * Handler for checking owner ID
 */
class MessageOwnerIdCheck extends AbstractHandler implements HandlerInterface
{
    /**
     * @var Destination
     */
    private $destination;

    /**
     * MessageOwnerIdCheck constructor.
     * @param Destination $destination
     */
    public function __construct(
        Destination $destination
    ) {
        $this->destination = $destination;
    }

    /**
     * {@inheritdoc}
     */
    public function handle(Record $recordToHandle, Record $oppositeRecord)
    {
        $this->validate($recordToHandle);
        $requestId = $recordToHandle->getValue('request_id');
        if ($recordToHandle->getValue('owner_type') == Owner::CUSTOMER) {
            $recordToHandle->setValue($this->field, $this->getCustomerIdByRequestId($requestId));
        } else {
            $recordToHandle->setValue($this->field, '0');
        }
    }

    /**
     * Get customer ID by request ID
     * @param int $requestId
     * @return string
     */
    private function getCustomerIdByRequestId($requestId)
    {
        $adapter = $this->destination->getAdapter();
        $query = $adapter->getSelect()
            ->from(
                ['aw_rma_request'],
                ['customer_id']
            )->where('id = ?', $requestId);

        if ($customerId = $query->getAdapter()->fetchCol($query)) {
            return $customerId[0];
        }
        return '0';
    }
}
