<?php
namespace Migration\Handler\AheadworksRma;

use Migration\ResourceModel\Record;
use Migration\Handler\AbstractHandler;
use Migration\Handler\HandlerInterface;
use Migration\ResourceModel\Source;

/**
 * Handler for correction order ID format
 */
class OrderIdFormat extends AbstractHandler implements HandlerInterface
{
    /**
     * @var Source
     */
    private $source;

    /**
     * OrderIdFormat constructor.
     * @param Source $source
     */
    public function __construct(
        Source $source
    ) {
        $this->source = $source;
    }

    /**
     * {@inheritdoc}
     */
    public function handle(Record $recordToHandle, Record $oppositeRecord)
    {
        $this->validate($recordToHandle);
        $incrementId = $recordToHandle->getValue('order_id');
        $recordToHandle->setValue($this->field, $this->getOrderIdByIncrementId($incrementId));
    }

    /**
     * Get order ID by increment ID
     *
     * @param int $incrementId
     * @return int
     */
    private function getOrderIdByIncrementId($incrementId)
    {
        $adapter = $this->source->getAdapter();
        $query = $adapter->getSelect()
            ->from(
                ['sales_flat_order'],
                ['entity_id']
            )->where('increment_id = ?', $incrementId);

        if ($orderId = $query->getAdapter()->fetchCol($query)) {
            return $orderId[0];
        }
        return $incrementId;
    }
}
