<?php
namespace Migration\Handler\AheadworksRma;

use Migration\ResourceModel\Record;
use Migration\Handler\AbstractHandler;
use Migration\Handler\HandlerInterface;
use Aheadworks\Rma\Api\Data\RequestPrintLabelInterface;
use Aheadworks\Rma\Api\Data\RequestPrintLabelInterfaceFactory;
use Magento\Framework\Api\DataObjectHelper;
use Magento\Framework\Reflection\DataObjectProcessor;

/**
 * Handler for correction print label format
 */
class PrintLabelFormat extends AbstractHandler implements HandlerInterface
{
    /**
     * @var DataObjectHelper
     */
    private $dataObjectHelper;

    /**
     * @var DataObjectProcessor
     */
    private $dataObjectProcessor;

    /**
     * @var RequestPrintLabelInterfaceFactory
     */
    private $requestPrintLabelFactory;

    /**
     * @param DataObjectHelper $dataObjectHelper
     * @param RequestPrintLabelInterfaceFactory $requestPrintLabelFactory
     * @param DataObjectProcessor $dataObjectProcessor
     */
    public function __construct(
        DataObjectHelper $dataObjectHelper,
        RequestPrintLabelInterfaceFactory $requestPrintLabelFactory,
        DataObjectProcessor $dataObjectProcessor
    ) {
        $this->dataObjectHelper = $dataObjectHelper;
        $this->dataObjectProcessor = $dataObjectProcessor;
        $this->requestPrintLabelFactory = $requestPrintLabelFactory;
    }

    /**
     * {@inheritdoc}
     */
    public function handle(Record $recordToHandle, Record $oppositeRecord)
    {
        $this->validate($recordToHandle);
        $oldPrintLabel = unserialize($recordToHandle->getValue('print_label'));
        $newPrintLabel = $this->convertOldNewPrintLabel($oldPrintLabel);

        if (is_array($newPrintLabel)) {
            $recordToHandle->setValue($this->field, serialize($newPrintLabel));
        }
    }

    /**
     * Convert old print label format to new format
     *
     * @param array $oldPrintLabel
     * @return array
     */
    private function convertOldNewPrintLabel($oldPrintLabel)
    {
        $newPrintLabelDataArray = [
            RequestPrintLabelInterface::REGION => isset($oldPrintLabel['stateprovince'])
                ? $oldPrintLabel['stateprovince'] : null,
            RequestPrintLabelInterface::REGION_ID => isset($oldPrintLabel['stateprovince_id'])
                ? $oldPrintLabel['stateprovince_id'] : null,
            RequestPrintLabelInterface::COUNTRY_ID => isset($oldPrintLabel['country_id'])
                ? $oldPrintLabel['country_id'] : null,
            RequestPrintLabelInterface::STREET => isset($oldPrintLabel['streetaddress'])
                ? $oldPrintLabel['streetaddress'] : null,
            RequestPrintLabelInterface::COMPANY => isset($oldPrintLabel['company'])
                ? $oldPrintLabel['company'] : null,
            RequestPrintLabelInterface::TELEPHONE => isset($oldPrintLabel['telephone'])
                ? $oldPrintLabel['telephone'] : null,
            RequestPrintLabelInterface::FAX => isset($oldPrintLabel['fax'])
                ? $oldPrintLabel['fax'] : null,
            RequestPrintLabelInterface::POSTCODE => isset($oldPrintLabel['postcode'])
                ? $oldPrintLabel['postcode'] : null,
            RequestPrintLabelInterface::CITY => isset($oldPrintLabel['city'])
                ? $oldPrintLabel['city'] : null,
            RequestPrintLabelInterface::FIRSTNAME => isset($oldPrintLabel['firstname'])
                ? $oldPrintLabel['firstname'] : null,
            RequestPrintLabelInterface::LASTNAME => isset($oldPrintLabel['lastname'])
                ? $oldPrintLabel['lastname'] : null,
            RequestPrintLabelInterface::MIDDLENAME => isset($oldPrintLabel['middlename'])
                ? $oldPrintLabel['middlename'] : null,
            RequestPrintLabelInterface::PREFIX => isset($oldPrintLabel['prefix'])
                ? $oldPrintLabel['prefix'] : null,
            RequestPrintLabelInterface::SUFFIX => isset($oldPrintLabel['suffix'])
                ? $oldPrintLabel['suffix'] : null,
            RequestPrintLabelInterface::VAT_ID => isset($oldPrintLabel['vat_id'])
                ? $oldPrintLabel['vat_id'] : null,
        ];

        $requestPrintLabelEntity = $this->requestPrintLabelFactory->create();

        $this->dataObjectHelper->populateWithArray(
            $requestPrintLabelEntity,
            $newPrintLabelDataArray,
            RequestPrintLabelInterface::class
        );

        return $this->dataObjectProcessor->buildOutputDataArray(
            $requestPrintLabelEntity,
            RequestPrintLabelInterface::class
        );
    }
}
