<?php
namespace Migration\Handler\AheadworksRma;

use Migration\ResourceModel\Record;
use Migration\Handler\AbstractHandler;
use Migration\Handler\HandlerInterface;
use Migration\ResourceModel\Source;

/**
 * Handler for correction store ID
 */
class Store extends AbstractHandler implements HandlerInterface
{
    /**
     * @var Source
     */
    private $source;

    /**
     * Store constructor.
     * @param Source $source
     */
    public function __construct(
        Source $source
    ) {
        $this->source = $source;
    }

    /**
     * {@inheritdoc}
     */
    public function handle(Record $recordToHandle, Record $oppositeRecord)
    {
        $this->validate($recordToHandle);
        $orderId = $recordToHandle->getValue('order_id');
        $recordToHandle->setValue($this->field, $this->getStoreIdByOrderId($orderId));
    }

    private function getStoreIdByOrderId($orderId)
    {
        $adapter = $this->source->getAdapter();
        $query = $adapter->getSelect()
            ->from(
                ['sales_flat_order'],
                ['store_id']
            )->where('entity_id = ?', $orderId);

        if ($storeId = $query->getAdapter()->fetchCol($query)) {
            return $storeId[0];
        }
        return 0;
    }
}
