<?php
namespace Migration\Step\AheadworksRma;

use Migration\ResourceModel\Destination;
use Migration\Reader\GroupsFactory;
use Migration\Config;

/**
 * Class Helper
 */
class Helper
{
    /**
     * @var Destination
     */
    protected $destination;

    /**
     * @var Config
     */
    protected $config;

    /**
     * @var \Migration\Reader\Groups
     */
    protected $readerGroups;

    /**
     * @var []
     */
    private $destinationCount;

    /**
     * @param GroupsFactory $groupsFactory
     * @param Destination $destination
     * @param Config $config
     */
    public function __construct(
        GroupsFactory $groupsFactory,
        Destination $destination,
        Config $config
    ) {
        $this->readerGroups = $groupsFactory->create('aw_rma_groups_file');
        $this->destination = $destination;
        $this->config = $config;
    }

    /**
     * Inserts data to specified table and returns last inserted ID
     *
     * @param $tableName
     * @param string $primaryKey
     * @param array $dataToInsert
     * @return int
     */
    public function makeInsert($tableName, $primaryKey, $dataToInsert)
    {
        /** @var \Magento\Framework\DB\Adapter\Pdo\Mysql $adapter */
        $adapter = $this->destination->getAdapter()->getSelect()->getAdapter();
        $adapter->insert($tableName, $dataToInsert);
        return $adapter->lastInsertId($tableName, $primaryKey);
    }

    /**
     * Get destination count for table name
     *
     * @param string $destinationName
     * @return null
     */
    public function getDestinationCount($destinationName)
    {
        return isset($this->destinationCount[$destinationName]) ? $this->destinationCount[$destinationName] : 0;
    }

    /**
     * Set destination count for table name
     *
     * @param string $destinationName
     * @return null
     */
    public function setDestinationCount($destinationName)
    {
        $this->destinationCount[$destinationName] = $this->destination->getRecordsCount($destinationName);
    }
}
